from . import Logger

def create(name : str = "", savetofile : bool = False, logfile : str = "log"):
    return Logger.SageLogger(name, savetofile, logfile)

def create_remote(method, url, headers, body, name : str = "", savetofile : bool = False, logfile : str = "log"):
    return Logger.SageRemoteLogger(method, url, headers, body, name, savetofile, logfile)

def create_discord_webhook_remote(url, name : str = "", savetofile : bool = False, logfile : str = "log"):
    return Logger.SageDiscordWebhookLogger.create(url, name, savetofile, logfile)

def create_temporary():
    return create(name="temporary", savetofile=False)


from setuptools import setup, find_packages

# Dane projektu
project_name = "SageLogger"
project_version = "1.0"
project_description = "Yet another python logger, or is it like any other?"
project_author = "PanSageYT"
project_author_email = "pansage@hugedick.fyi"

# Zależności
dependencies = [
    "colorama",
    "requests"
]

# Odczytaj zawartość README.md jako długopis
with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()

setup(
    name=project_name,
    version=project_version,
    author=project_author,
    author_email=project_author_email,
    description=project_description,
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/PanSageYT/SageLogger",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    packages=find_packages(),
    python_requires=">=3.7",
    install_requires=dependencies
)
